---
title: "Basics"
description: ""
icon: "play"
---


---

```python
from openbrowser import Agent, Browser, ChatBrowserUse

browser = Browser(
	headless=False,  # Show browser window
	window_size={'width': 1000, 'height': 700},  # Set window size
)

agent = Agent(
	task='Search for OpenBrowser',
	browser=browser,
	llm=ChatBrowserUse(),
)


async def main():
	await agent.run()
```
